@@ -1,7 +1,7 @@
 ### Test 8: Fail gracefully on no connection               ####
 #   If internet connection is down, retry n_retries times. After n_retries,
 #   exit gracefully returning NULL with a message.
-context("MODIStsp Test 8: Exit gracefully on missing internet connection")
+message("MODIStsp Test 8: Exit gracefully on missing internet connection")
 test_that(
   "Tests on MODIStsp", {
     skip_on_cran()
