@@ -5,7 +5,7 @@ test_that("MODIStsp_readxml works as expected", {
 
   tmpfile <- tempfile(fileext = ".RData")
   # read the xml file of products options
-  MODIStsp_read_xml(tmpfile, system.file("ExtData", "MODIStsp_ProdOpts.xml",
+  MODIStsp_read_xml(tmpfile, system.file("ExtData", "MODIStsp_ProdOpts.xml.zip",
                                         package = "MODIStsp"))
   # load the saved opts file
   opts <- get(load(tmpfile))
